# KosmoS Python API

python library to communicate with the KosmoS infrastructure.


## install with pip
`pip install kosmos-client`

## examples
see examples directory
## reference
see docs directory or https://kosmos-lab.github.io/python-kosmos-client/ 
